@@ -138,14 +138,6 @@ bool AmmoEffect::render() const {
 	return false;
 }
 
-/*#if defined(Q_OS_SYMBIAN)
-// fades seem slower on Symbian (Nokia 5800), for some reason?
-const int fade_time_c = 500;
-const int whitefade_time_c = 500;
-#else
-const int fade_time_c = 1000;
-const int whitefade_time_c = 1000;
-#endif*/
 const int fade_time_c = 1000;
 const int whitefade_time_c = 1000;
 
@@ -257,6 +249,7 @@ GameState::GameState() {
 	//this->effects = new Vector();
 	//this->effects = new vector<TimedEffect *>();
 	this->screen_page = new PanelPage(0, 0);
+	this->screen_page->setTolerance(0);
 	this->mobile_ui_display_mouse = false;
 	this->mouse_image = NULL;
 	this->mouse_off_x = 0;
@@ -474,6 +467,9 @@ PanelPage *PlaceMenGameState::getMapPanel(int x, int y) {
 
 void PlaceMenGameState::reset() {
     //LOG("PlaceMenGameState::reset()\n");
+	/*if( !_CrtCheckMemory() ) {
+		throw "_CrtCheckMemory FAILED";
+	}*/
 	this->screen_page->free(true);
 
 	if( this->choosemenPanel != NULL ) {
@@ -499,6 +495,9 @@ void PlaceMenGameState::reset() {
 			}
 		}
 	}
+	/*if( !_CrtCheckMemory() ) {
+		throw "_CrtCheckMemory FAILED";
+	}*/
 }
 
 void PlaceMenGameState::draw() {
@@ -950,6 +949,7 @@ void PlayingGameState::setupMapGUI() {
 					int map_x = offset_map_x_c + 16 * x;
 					int map_y = offset_map_y_c + 16 * y;
 					PanelPage *panel = new PanelPage(map_x, map_y, 16, 16);
+					panel->setTolerance(0); // since map sectors are aligned, better for touchscreens not to use the "tolerance"
 					panel->setInfoLMB("view this sector");
 					screen_page->add(panel);
 					//map->panels[x][y] = panel;
@@ -1088,7 +1088,8 @@ void PlayingGameState::resetShieldButtons() {
 			n_sides++;
 			shield_buttons[i] = new ImageButton(offset_map_x_c + 16 * map_width_c + 4, offset_map_y_c + shield_step_y_c * i + 8, playershields[ Player::getShieldIndex(allied) ]);
 			screen_page->add(shield_buttons[i]);
-			shield_number_panels[i] = new PanelPage(offset_map_x_c + 16 * map_width_c + 4 + 16, offset_map_y_c + shield_step_y_c * i + 8, 20, 10);
+			//shield_number_panels[i] = new PanelPage(offset_map_x_c + 16 * map_width_c + 4 + 16, offset_map_y_c + shield_step_y_c * i + 8, 20, 10);
+			shield_number_panels[i] = new PanelPage(offset_map_x_c + 16 * map_width_c + 4 + 16, offset_map_y_c + shield_step_y_c * i + 8, 20, shield_step_y_c);
 			screen_page->add(shield_number_panels[i]);
 		}
 	}
@@ -1298,8 +1299,21 @@ void PlayingGameState::draw() {
 
 			if( i == BUILDING_TOWER )
 				flags[ current_sector->getPlayer() ][frame_counter % n_flag_frames_c]->draw(offset_land_x_c + building->getX() + offset_flag_x_c, offset_land_y_c + building->getY() + offset_flag_y_c, true);
-		}
 
+			const int health_xpos = offset_land_x_c + building->getX();
+			//const int health_ypos = offset_land_y_c + building->getY() - 16;
+			const int health_ypos = offset_land_y_c + building->getY() + images[ current_sector->getBuildingEpoch() ]->getScaledHeight() + 2;
+			const int health_width = 32;
+			const int health_height = 4;
+			/*float health = (health_width-2) * ((float)building->getHealth()) / (float)building->getMaxHealth();
+			screen->fillRectWithAlpha(scale_width*health_xpos, scale_height*health_ypos, scale_width*health_width, scale_height*health_height, 255, 255, 255, 127);
+			screen->fillRectWithAlpha(scale_width*(health_xpos+1), scale_height*(health_ypos+1), scale_width*(health_width-2), scale_height*(health_height-2), 0, 0, 0, 127);
+			screen->fillRectWithAlpha(scale_width*(health_xpos+1), scale_height*(health_ypos+1), scale_width*health, scale_height*(health_height-2), 255, 0, 0, 127);*/
+			float health = (scale_width*health_width-2) * ((float)building->getHealth()) / (float)building->getMaxHealth();
+			screen->fillRect(scale_width*health_xpos, scale_height*health_ypos, scale_width*health_width, scale_height*health_height, 255, 255, 255);
+			screen->fillRect(scale_width*health_xpos+1, scale_height*health_ypos+1, scale_width*health_width-2, scale_height*health_height-2, 0, 0, 0);
+			screen->fillRect(scale_width*health_xpos+1, scale_height*health_ypos+1, health, scale_height*health_height-2, 255, 0, 0);
+		}
 	}
 	else if( current_sector->getPlayer() != -1 ) {
 		ASSERT( current_sector->isShutdown() );
