@@ -178,16 +178,21 @@ ChooseMenPanel::ChooseMenPanel(PlaceMenGameState *gamestate) : MultiPanel(N_STAT
     cy += step_y;
     this->addToPanel(STATE_CHOOSEISLAND, button_help);
 #endif
+#if defined(Q_OS_ANDROID)
+	// Applications don't quit on Android
+	this->button_quit = NULL;
+#else
     this->button_quit = new Button((int)(mx - 2.0*fw), cy, "QUIT", letters_large);
     cy += step_y;
     this->addToPanel(STATE_CHOOSEISLAND, button_quit);
+#endif
 
     //this->button_nmen = new PanelPage(mx - 12, 154, 24, 12);
     this->button_nmen = new PanelPage(mx - 12, 154, 24, 32);
     this->addToPanel(STATE_CHOOSEMEN, button_nmen);
 
     cy = start_y;
-    step_y = 20;
+    step_y = 26;
     this->button_continue = new Button((int)(mx - 4.0*fw), cy, "CONTINUE", letters_large);
     cy += step_y;
     this->addToPanel(STATE_OPTIONS, button_continue);
@@ -199,7 +204,7 @@ ChooseMenPanel::ChooseMenPanel(PlaceMenGameState *gamestate) : MultiPanel(N_STAT
     this->button_music->setActive( play_music ? 0 : 1 );
 	this->addToPanel(STATE_OPTIONS, button_music);
 
-#if defined(Q_OS_SYMBIAN) || defined(Q_WS_SIMULATOR) || defined(Q_WS_MAEMO_5)
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_SIMULATOR) || defined(Q_WS_MAEMO_5) || defined(Q_OS_ANDROID)
     this->button_onemousebutton = NULL;
 #else
 	char *onemousebutton_texts[] = { "ONE MOUSE BUTTON UI", "TWO MOUSE BUTTON UI" };
@@ -434,7 +439,7 @@ void ChooseMenPanel::input(int m_x,int m_y,bool m_left,bool m_middle,bool m_righ
             QDesktopServices::openUrl(QUrl("http://homepage.ntlworld.com/mark.harman/comp_gigalomania.html"));
         }
 #endif
-        else if( m_left && click && this->button_quit->mouseOver(m_x, m_y) ) {
+        else if( m_left && click && this->button_quit != NULL && this->button_quit->mouseOver(m_x, m_y) ) {
             done = true;
             //quitGame();
             gamestate->requestQuit();
@@ -493,8 +498,7 @@ void ChooseMenPanel::input(int m_x,int m_y,bool m_left,bool m_middle,bool m_righ
                     done = true;
                     registerClick();
                     loadGame(i);
-					this->c_page = STATE_CHOOSEISLAND;
-					return; // hack - need to return, as loading the game destroys this class!
+					return; // hack - need to return, as loading the game destroys this class! (the gamestate will be reset - which will also switch the c_page back to STATE_CHOOSEISLAND)
 				}
 			}
 		}
@@ -726,7 +730,7 @@ void GamePanel::setup() {
 	xpos += step_x;
 
 	// SHIELD
-	this->button_bigshield = new ImageButton(33, 0, panel_bigshield, "return to main screen");
+	this->button_bigshield = new ImageButton(33, 0, 32, 16, panel_bigshield, "return to main screen");
 	this->addToPanel(STATE_SHIELD, button_bigshield);
 	for(int i=0;i<n_sub_epochs;i++) {
 		this->button_deploy_shields[i] = new ImageButton(28 + 22*i, 24, icon_shields[i]);
@@ -737,7 +741,7 @@ void GamePanel::setup() {
 	this->addToPanel(STATE_SHIELD, button_shutdown);
 
 	// DEFENCE
-	this->button_bigdefence = new ImageButton(33, 0, panel_bigdefence, "return to main screen");
+	this->button_bigdefence = new ImageButton(33, 0, 32, 16, panel_bigdefence, "return to main screen");
 	this->addToPanel(STATE_DEFENCE, button_bigdefence);
 	for(int i=0;i<n_sub_epochs;i++) {
 		this->button_deploy_defences[i] = new ImageButton(28 + 22*i, 24, numbered_defences[start_epoch + i]);
@@ -747,14 +751,15 @@ void GamePanel::setup() {
 	}
 
 	// ATTACK
-	this->button_bigattack = new ImageButton(33, 0, panel_bigattack, "return to main screen");
+	this->button_bigattack = new ImageButton(33, 0, 32, 16, panel_bigattack, "return to main screen");
 	this->addToPanel(STATE_ATTACK, button_bigattack);
 	this->button_deploy_unarmedmen = new ImageButton(offset_attack_x_c, 24, 16, 28, unarmed_man);
 	//this->button_deploy_unarmedmen = new ImageButton(offset_attack_x_c, 24, 16, 28, men[gamestate->getCurrentSector()->getBuildingEpoch()]);
 	this->button_deploy_unarmedmen->setInfoLMB("add an unarmed man to the army");
 	this->addToPanel(STATE_ATTACK, button_deploy_unarmedmen);
 	for(int i=0;i<n_sub_epochs;i++) {
-		this->button_deploy_attackers[i] = new ImageButton(offset_attack_x_c + space_attack_x_c*i, 56, 16, 28, numbered_weapons[start_epoch + i]);
+		//this->button_deploy_attackers[i] = new ImageButton(offset_attack_x_c + space_attack_x_c*i, 56, 16, 28, numbered_weapons[start_epoch + i]);
+		this->button_deploy_attackers[i] = new ImageButton(offset_attack_x_c + space_attack_x_c*i, 56, 16, 40, numbered_weapons[start_epoch + i]);
 		sprintf(buffer, "add a %s to the army", Invention::getInvention(Invention::WEAPON, start_epoch + i)->getName());
 		this->button_deploy_attackers[i]->setInfoLMB(buffer);
 		this->addToPanel(STATE_ATTACK, button_deploy_attackers[i]);
@@ -764,9 +769,10 @@ void GamePanel::setup() {
 	this->addToPanel(STATE_ATTACK, button_return_attackers);
 
 	// DESIGN
-	this->button_bigdesign = new ImageButton(33, 0, panel_bigdesign, "return to main screen");
+	this->button_bigdesign = new ImageButton(33, 0, 32, 16, panel_bigdesign, "return to main screen");
 	this->addToPanel(STATE_DESIGN, button_bigdesign);
-	this->button_designers = new ImageButton(40, 16, 16, 28, men[gamestate->getCurrentSector()->getBuildingEpoch()]);
+	//this->button_designers = new ImageButton(40, 16, 16, 28, men[gamestate->getCurrentSector()->getBuildingEpoch()]);
+	this->button_designers = new ImageButton(40, 16, 16, 40, men[gamestate->getCurrentSector()->getBuildingEpoch()]);
 	if( onemousebutton ) {
 		this->button_designers->setInfoLMB("change the number of designers");
 	}
@@ -792,7 +798,7 @@ void GamePanel::setup() {
 	}
 
 	// ELEMENTSTOCKS
-	this->button_bigelementstocks = new ImageButton(33, 0, mine_gatherable_large, "return to main screen");
+	this->button_bigelementstocks = new ImageButton(33, 0, 32, 16, mine_gatherable_large, "return to main screen");
 	this->addToPanel(STATE_ELEMENTSTOCKS, button_bigelementstocks);
 	for(int i=0;i<4;i++) {
 		if( this->element_index[i] == -1 ) {
@@ -819,11 +825,12 @@ void GamePanel::setup() {
 	}
 
 	// BUILD
-	this->button_bigbuild = new ImageButton(33, 0, panel_bigbuild, "return to main screen");
+	this->button_bigbuild = new ImageButton(33, 0, 32, 16, panel_bigbuild, "return to main screen");
 	this->addToPanel(STATE_BUILD, button_bigbuild);
 	for(int i=0;i<N_BUILDINGS;i++)
 		this->button_nbuilders2[i] = NULL;
-	this->button_nbuilders2[BUILDING_MINE] = new ImageButton(40, 20, 19, 28, panel_build[BUILDING_MINE]);
+	//this->button_nbuilders2[BUILDING_MINE] = new ImageButton(40, 20, 19, 28, panel_build[BUILDING_MINE]);
+	this->button_nbuilders2[BUILDING_MINE] = new ImageButton(40, 20, 19, build_step_y_c, panel_build[BUILDING_MINE]);
 	if( onemousebutton ) {
 		this->button_nbuilders2[BUILDING_MINE]->setInfoLMB("change the number of builders\nbuilding a mine");
 	}
@@ -832,7 +839,8 @@ void GamePanel::setup() {
 		this->button_nbuilders2[BUILDING_MINE]->setInfoRMB("increase the number of builders\nbuilding a mine");
 	}
 	this->addToPanel(STATE_BUILD, button_nbuilders2[BUILDING_MINE]);
-    this->button_nbuilders2[BUILDING_FACTORY] = new ImageButton(40, 20 + build_step_y_c, 19, 28, panel_build[BUILDING_FACTORY]);
+    //this->button_nbuilders2[BUILDING_FACTORY] = new ImageButton(40, 20 + build_step_y_c, 19, 28, panel_build[BUILDING_FACTORY]);
+    this->button_nbuilders2[BUILDING_FACTORY] = new ImageButton(40, 20 + build_step_y_c, 19, build_step_y_c, panel_build[BUILDING_FACTORY]);
     if( onemousebutton ) {
 		this->button_nbuilders2[BUILDING_FACTORY]->setInfoLMB("change the number of builders\nbuilding a factory");
 	}
@@ -841,7 +849,8 @@ void GamePanel::setup() {
 		this->button_nbuilders2[BUILDING_FACTORY]->setInfoRMB("increase the number of builders\nbuilding a factory");
 	}
 	this->addToPanel(STATE_BUILD, button_nbuilders2[BUILDING_FACTORY]);
-    this->button_nbuilders2[BUILDING_LAB] = new ImageButton(40, 20 + 2*build_step_y_c, 19, 28, panel_build[BUILDING_LAB]);
+    //this->button_nbuilders2[BUILDING_LAB] = new ImageButton(40, 20 + 2*build_step_y_c, 19, 28, panel_build[BUILDING_LAB]);
+    this->button_nbuilders2[BUILDING_LAB] = new ImageButton(40, 20 + 2*build_step_y_c, 19, build_step_y_c, panel_build[BUILDING_LAB]);
     if( onemousebutton ) {
 		this->button_nbuilders2[BUILDING_LAB]->setInfoLMB("change the number of builders\nbuilding a lab");
 	}
@@ -852,7 +861,7 @@ void GamePanel::setup() {
 	this->addToPanel(STATE_BUILD, button_nbuilders2[BUILDING_LAB]);
 
 	// KNOWNDESIGNS
-	this->button_bigknowndesigns = new ImageButton(33, 0, panel_bigknowndesigns, "return to main screen");
+	this->button_bigknowndesigns = new ImageButton(33, 0, 32, 16, panel_bigknowndesigns, "return to main screen");
 	this->addToPanel(STATE_KNOWNDESIGNS, button_bigknowndesigns);
 	for(int i=0;i<n_sub_epochs;i++) {
         //int this_y = 40 + i*16;
@@ -874,16 +883,17 @@ void GamePanel::setup() {
 	this->button_bigdesigninfo = new ImageButton(33, 0, panel_bigknowndesigns, "view blueprints\nof completed designs");
 	this->addToPanel(STATE_DESIGNINFO, button_bigdesigninfo);
 	this->button_trashdesign = new ImageButton(64, 100, icon_trash);
-	if( onemousebutton ) {
+	/*if( onemousebutton ) {
 		button_trashdesign->setInfoLMB("trash this design");
 	}
 	else {
 		button_trashdesign->setInfoBMB("trash this design");
-	}
+	}*/
+	button_trashdesign->setInfoLMB("trash this design");
 	this->addToPanel(STATE_DESIGNINFO, button_trashdesign);
 
 	// FACTORY
-	this->button_bigfactory = new ImageButton(33, 0, panel_bigfactory, "return to main screen");
+	this->button_bigfactory = new ImageButton(33, 0, 32, 16, panel_bigfactory, "return to main screen");
 	this->addToPanel(STATE_FACTORY, button_bigfactory);
 	//this->button_workers = new ImageButton(40, 16, 16, 28, men[gamestate->getCurrentSector()->getBuildingEpoch()]);
 	this->button_workers = new ImageButton(40, 14, 16, 26, men[gamestate->getCurrentSector()->getBuildingEpoch()]);
@@ -1301,14 +1311,17 @@ void GamePanel::draw() {
 			if( gamestate->getCurrentSector()->getBuilding((Type)i) != NULL ) {
 				int width = building_health->getScaledWidth();
 				int health = gamestate->getCurrentSector()->getBuilding((Type)i)->getHealth();
+				int max_health = gamestate->getCurrentSector()->getBuilding((Type)i)->getMaxHealth();
+				//health = 50;
+				//max_health = 60;
 				int offx = offset_panel_x_c + 24;
 				/*rect.x = (short)(scale_width * ( offset_panel_x_c + 24 ));
 				rect.y = (short)(scale_height * ( offset_panel_y_c + 64 + 16 * i ));
 				rect.w = (short)(( scale_width * health ) * 0.6);
 				rect.h = (short)(scale_height * 4);*/
-				short x = (short)(scale_width * offx + ( scale_width * health * width ) / 100.0);
+				short x = (short)(scale_width * offx + ( scale_width * health * width ) / (float)max_health);
 				short y = (short)(scale_height * ( offset_panel_y_c + 64 + 16 * i ));
-				short w = (short)ceil(( scale_width * (100 - health) * width ) / 100.0);
+				short w = (short)ceil(( scale_width * (max_health - health) * width ) / (float)max_health);
 				short h = (short)(scale_height * 5);
 				building_health->draw(offx, (int)(y/scale_height), true);
 				screen->fillRect(x, y, w, h, 0, 0, 0);
@@ -1382,12 +1395,14 @@ void GamePanel::draw() {
 			int n_elements = 0, fraction = 0;
 			gamestate->getCurrentSector()->getElementStocks(&n_elements, &fraction, element);
 			int off = 0;
+			//int ypos = offset_panel_y_c + 38 + 28 * i;
+			int ypos = offset_panel_y_c + 40 + 28 * i;
 			if( n_elements > 0 ) {
-				Image::writeNumbers(offset_panel_x_c + 72, offset_panel_y_c + 38 + 28 * i, numbers_blue, n_elements, Image::JUSTIFY_LEFT, true);
+				Image::writeNumbers(offset_panel_x_c + 72, ypos, numbers_blue, n_elements, Image::JUSTIFY_LEFT, true);
 				off += 8 * n_digits(n_elements);
 			}
 			if( fraction == 1 ) {
-				numbers_half->draw(offset_panel_x_c + 72 + off, offset_panel_y_c + 38 + 28 * i, true);
+				numbers_half->draw(offset_panel_x_c + 72 + off, ypos, true);
 			}
 			/*if( n_elements > 0 || fraction > 0 ) {
 			Image::writeNumbers(offset_panel_x_c + 72, offset_panel_y_c + 38 + 28*i, numbers_grey, n_elements, Image::JUSTIFY_CENTRE, true);
@@ -1404,7 +1419,8 @@ void GamePanel::draw() {
 		for(int i=0;i<N_BUILDINGS;i++)
 		{
 			if( this->button_nbuilders2[i] != NULL && this->button_nbuilders2[i]->isEnabled() ) {
-				Image::writeNumbers( this->button_nbuilders2[i]->getXCentre(), this->button_nbuilders2[i]->getBottom() - 8, numbers_white, gamestate->getCurrentSector()->getBuilders((Type)i),Image::JUSTIFY_CENTRE,true);
+				//Image::writeNumbers( this->button_nbuilders2[i]->getXCentre(), this->button_nbuilders2[i]->getBottom() - 8, numbers_white, gamestate->getCurrentSector()->getBuilders((Type)i),Image::JUSTIFY_CENTRE,true);
+				Image::writeNumbers( this->button_nbuilders2[i]->getXCentre(), this->button_nbuilders2[i]->getTop() + 20, numbers_white, gamestate->getCurrentSector()->getBuilders((Type)i),Image::JUSTIFY_CENTRE,true);
 				if( gamestate->getCurrentSector()->getBuilders((Type)i) > 0 ) {
 					int halfdays = 0, hours = 0;
 					gamestate->getCurrentSector()->buildingTimeLeft((Type)i, &halfdays, &hours);
@@ -2059,7 +2075,8 @@ x		}*/
             registerClick();
             this->setPage(STATE_KNOWNDESIGNS);
 		}
-		if( ( onemousebutton ? m_left : ( m_left && m_right ) ) && click && this->button_trashdesign->mouseOver(m_x,m_y) ) {
+		//if( ( onemousebutton ? m_left : ( m_left && m_right ) ) && click && this->button_trashdesign->mouseOver(m_x,m_y) ) {
+		if( m_left && click && this->button_trashdesign->mouseOver(m_x,m_y) ) {
             done = true;
             registerClick();
             this->setPage(STATE_KNOWNDESIGNS);
